/* $Id: //guest/paul_krause/perforce/integrations/jdev/src/com/perforce/jdev/P4EditCmd.java#6 $
 * Copyright 2000-2002 SoundBite Corporation.   All Rights Reserved.
 */
package com.perforce.jdev;

import java.awt.Dimension;
import java.util.Iterator;
import javax.swing.Icon;
import javax.swing.KeyStroke;

import oracle.ide.scm.SCMControlItem;
import oracle.ide.scm.SCMDialogSpecification;
import oracle.ide.scm.SCMFile;
import oracle.ide.scm.SCMFileContext;
import oracle.ide.scm.SCMOptions;
import oracle.ide.scm.SCMOptionsCustomizer;
import oracle.ide.scm.error.SCMException;
import oracle.ide.scm.op.SCMMultiFileOperation;

import com.perforce.jdev.res.Icons;


/**
 * Implements the "p4 edit" command
 *
 * @author Paul Krause
 * @version Release 0 $Revision: #6 $
 */
public class P4EditCmd extends SCMMultiFileOperation
   implements SCMControlItem, SCMDialogSpecification
{

   /**
    * Gets the value of the control item property
    *
    * @return The ControlItem value
    */
   public SCMControlItem getControlItem()
   {
      return this;
   }

   /**
    * Gets the value of the name property
    *
    * @return The Name value
    */
   public String getName()
   {
      return "p4 edit ...";
   }

   /**
    * Gets the value of the mnemonic property
    *
    * @return The Mnemonic value
    */
   public char getMnemonic()
   {
      return 'e';
   }

   /**
    * Gets the value of the accelerator property
    *
    * @return The Accelerator value
    */
   public KeyStroke getAccelerator()
   {
      return null;
   }

   /**
    * Gets the specification for a dialog that allows user to set
    * command options.
    *
    * @return a <code>SCMDialogSpecification</code> value
    */
   public SCMDialogSpecification getDialogSpecification() {
      return this;
   }

   /**
    * Gets the value of the icon property
    *
    * @return The Icon value
    */
   public Icon getIcon() {
      return Icons.CHECKOUT;
   }

   /**
    * Gets the value of the context item property
    *
    * @return The ContextItem value
    */
   public boolean isContextItem()
   {
      return true;
   }

   /**
    * Determines whether this command is enabled.
    *
    * @param control Is the addin enabled?
    * @return The Enabled value
    */
   public boolean isEnabled(boolean control)
   {
      return control;
   }

   /**
    * Gets the value of the filter disables property
    *
    * @return The FilterDisables value
    */
   public boolean getFilterDisables()
   {
      return true;
   }

   /**
    * Gets the value of the file context property.
    *
    * @return The FileContext value
    */
   public byte getFileContext()
   {
      return SCMFileContext.CONTEXT_ANY;
   }

   /**
    * Executes this command on multiple files.
    *
    * @param files an <code>Iterator</code> value
    * @param opts a <code>SCMOptions</code> value
    * @exception SCMException if an error occurs
    */
   public void execute (Iterator files, SCMOptions opts)
      throws SCMException
   {
      while (files.hasNext()) {
         final SCMFile file = (SCMFile) files.next();
         final P4Node node = (P4Node) file.getStatus();
         node.openForEdit(opts);
      }
   }

   /**
    * Opens a file for editing.
    *
    * @param file that user wants to edit
    * @param opts Command options
    * @exception SCMException if an error occurs
    */
   public void execute(SCMFile file, SCMOptions opts)
      throws SCMException
   {
      final P4Node node = (P4Node) file.getStatus();
      node.openForEdit(opts);
   }

   /**
    * Determines whether a file can be opened for editing.
    *
    * @param file to consider for editing
    * @return true if edit applies to file
    * @exception SCMException if getStatus fails
    */
   public boolean filter(SCMFile file)
      throws SCMException
   {
      final P4Node state = (P4Node) file.getStatus();
      return state.isControlled() && !state.isOpen();
   }

   /**
    * Gets the caption of this options dialog.
    *
    * @return a caption <code>String</code>
    */
   public String getCaption() {
      return "p4 edit - Select files";
   }

   /**
    * Gets the long prompt of this options dialog.
    *
    * @return a <code>String</code> value
    */
   public String getLongPrompt() {
      return "Select or deselect files to open for editing";
   }

   /**
    * Gets the description of the action for the progress dialog.
    *
    * @return a <code>String</code> value
    */
   public String getWatcherDescription() {
      return "Checking out files from depot";
   }

   /**
    * This dialog specification has no options customizer.
    *
    * @return a <code>null</code> value
    */
   public SCMOptionsCustomizer getOptionsCustomizer() {
      return null;
   }

   /**
    * This dialog specifiaction allows user to modify files.
    *
    * @return a <code>boolean</code> value
    */
   public boolean isModifiable() {
      return true;
   }

   public Dimension getSize() {
      return null;
   }

   public boolean isLayoutVertical() {
      return true;
   }

   public boolean isWatcherIndeterminate() {
      return false;
   }
}
