package com.perforce.jdev.cm;
import com.perforce.api.Client;
import com.perforce.api.Env;
import com.perforce.api.PerforceException;

import com.perforce.jdev.res.Icons;

import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import javax.swing.Icon;

import oracle.ide.model.Attributes;
import oracle.ide.model.DefaultNode;

import oracle.jdeveloper.cm.CMException;
import oracle.jdeveloper.cm.ConnectionDescriptor;
import oracle.jdeveloper.cm.ConnectionWrapper;

/**
 * Part of ConnectionManager pattern.
 *
 * @author Paul Krause
 * @version $Revision: #1 $ $Date: 2002/10/05 $
 */
public class P4ConnectionWrapper extends DefaultNode
   implements ConnectionWrapper
{
   private final Client p4Conn;
   private final ConnectionDescriptor wrappedDescriptor;

   /** The {@link Env} presentation. */
   public static final String ENV = Env.class.getName();

   /** The {@link Client} presentation. */
   public static final String CLIENT = Client.class.getName();

   public P4ConnectionWrapper(ConnectionDescriptor cd) {
      final String name = cd.getConnectionName();
      final Env env = new Env(cd);
      p4Conn = new Client(env, name);
      wrappedDescriptor = cd;
   }

   public ConnectionDescriptor getDescriptor() {
      return wrappedDescriptor;
   }

   public Object getPresentation(String p0) throws CMException {
      if (p0.equals(ENV)) return p4Conn.getEnv();
      if (p0.equals(CLIENT)) return p4Conn;
      throw new CMException("Unknown presentation " + p0);
   }

   public boolean containsPresentation(String p0) {
      return (p0.equals(ENV) || p0.equals(CLIENT));
   }

   public Iterator getPresentationIterator() {
      final Object[] parray = new Object[] { p4Conn, p4Conn.getEnv() };
      final List plist = Arrays.asList(parray);
      return plist.iterator();
   }

   public void closeConnection() {
      p4Conn.invalidate();
      p4Conn.clearCache();
   }

   public void testPresentation(String p0) throws CMException {
      try {
         p4Conn.getEnv().checkValidity();
      } catch (PerforceException e) {
         throw new CMException(e);
      }
   }

   public Attributes getAttributes() {
      // TODO:  Override this DefaultNode method
      return super.getAttributes();
   }

   public Client getClient() {
      return p4Conn;
   }

   public Icon getIcon() {
      return Icons.DEPOT;
   }

   public String getShortLabel() {
      return p4Conn.getName();
   }

}
